package hu.uniobuda.nik;

import android.app.Activity;
import android.content.ContentValues;
import android.database.Cursor;
import android.database.sqlite.SQLiteDatabase;
import android.os.Bundle;
import android.util.Log;
import android.view.View;
import android.view.View.OnClickListener;
import android.widget.Button;

/**
 * Ez a kis plda program bemutatja, hogyan lehet a legegyszerbben hasznlni 
 * az SQLite-ot Androidban.
 * 
 * Nincsenek hibakezelsek, s a lehet legegyszerbb hasznlatot mutatja be.
 *
 */

public class MainActivity extends Activity {
	
	// Egy adatbzis nv, s egy tbla nv amivel dolgozunk
	// final, mert gysem mdostjuk ksbb (s gyorst is)
	final static String DB_NAME 		= "my_database.db",
				  		TABLE_NAME		= "main";
	
	// Az adatbzis kezel
	SQLiteDatabase db;
	
	// A 4 gomb elrshez
	Button b1, b2, b3, b4, b5;
	
    /** Called when the activity is first created. */
    @Override
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.main);
        
        // 4 darab gomb elrse
        b1 = (Button)findViewById(R.id.button1);
        b2 = (Button)findViewById(R.id.button2);
        b3 = (Button)findViewById(R.id.button3);
        b4 = (Button)findViewById(R.id.button4);
        b5 = (Button)findViewById(R.id.button5);
        
        // Adatbzis definils, ltrehozza s/vagy megnyitja az adatbzist
        db = openOrCreateDatabase(DB_NAME, SQLiteDatabase.CREATE_IF_NECESSARY, null);
        
        // TBLA ltrehozsa, viszont csak akkor ha nem ltezik, 
        // mivel tbbszr is elindthatjuk az alkalmazsunkat.
        // Ha ezt nem kezelnnk 2. indtsra hibt dobna mivel
        // mr ltezik ilyen tbla.
        // execSQL: tetszleges SQL kd futtatsa
        db.execSQL("CREATE TABLE IF NOT EXISTS " + TABLE_NAME + "(" +
		        		"id		INTEGER PRIMARY KEY AUTOINCREMENT," +
		        		"uname	TEXT" +
        			")");
        
        
        // 1.) INSERT
        b1.setOnClickListener(new OnClickListener() {
			public void onClick(View v) {
				// Kell egy rtktrol, amibe beletesszk a beszrand sor adatait
				ContentValues values = new ContentValues();
				// uname oszlop prtke az : Android
				values.put("uname", "Andro");
				// Beszrjuk s mivel AUTOINCREMENT PRIMARY KEY 
				// visszakapjuk a beszrt sorhoz tartoz ID-t
				long id = db.insert(TABLE_NAME, null, values);
				
				Log.d("NIK", "INSERT: " + id);				
			}
		});
        
        // 2.) SELECT
        b2.setOnClickListener(new OnClickListener() {
			public void onClick(View v) {
				// Lekrdezshez megadhatunk sok-sok szoksos felttelt, most: WHERE id > 2 ...
				Cursor cur = db.query(TABLE_NAME, null, "id>?", new String[]{"2"}, null, null, null);
				// Mutatt clszer elre mozgatni, mert ha egy metdusba
				// tesszk brmikor meghvhatjuk, s brhol lhat a mutat
				cur.moveToFirst();
				// Addg megynk amg nem igaz, hogy az utolsval vgeztnk
				while(!cur.isAfterLast()){
					
					// Tudnunk kell, hogy az adott oszlopban lv adat milyen tpus
					// cur.getLong(0): ez a 0. oszlop vagyis ID oszlop rtke, ami INTEGER
					// cur.getString(1): ez az 1. oszlop, vagyis UNAME oszlop rtke, ami STRING (=TEXT)
					Log.d("NIK", "ID: " + cur.getInt(0) + " UNAME: " + cur.getString(1));
					
					// Mutat tovbblptetse
					cur.moveToNext();
				}
				cur.close();
				
			}
		});
        
        // 3.) UPDATE
        b3.setOnClickListener(new OnClickListener() {
			public void onClick(View v) {
				// Hasonlan, mint INSERT esetn, kell az j adatnak egy trol
				ContentValues updateValues = new ContentValues();
				updateValues.put("uname", "Quadro");
				// Frissts az adatbzisban, 
				// felttelek megadsa ugyangy lehetsges, mint SELECT esetn:
				// UPDATE TABLE main SET(uname = 'Quadro') WHERE id < 10
				db.update(TABLE_NAME, updateValues, "id < ?", new String[]{"10"});				
			}
		});
        
        // 4.) DELETE
        b4.setOnClickListener(new OnClickListener() {
			public void onClick(View v) {
				// Trkjk az adott tbla tartalmt
				// (Ugye itt az ID (autoincrement) bels szmllja nem indul jra!)
				db.delete(TABLE_NAME, null, null);				
			}
		});
        
        // 5.) DROP
        b5.setOnClickListener(new OnClickListener() {
			public void onClick(View v) {
				// Egyszeren SQL tring lefuttatsa tbla eldobshoz
				db.execSQL("DROP TABLE IF EXISTS " + TABLE_NAME);				
			}
		});
        
    }
    
    
    
    
    
    
    
    
    
    
}